pub(crate) enum TypeOwnerId {
GenericDefId(GenericDefId),
BuiltinDeriveImplId(BuiltinDeriveImplId),
NoParams(Crate),
}Variants
Implementations
Sourceimpl TypeOwnerId
impl TypeOwnerId
Sourcepub(crate) fn from_anon_const<'db>(
id: AnonConstId<'db>,
db: &'db dyn HirDatabase,
) -> TypeOwnerId
pub(crate) fn from_anon_const<'db>( id: AnonConstId<'db>, db: &'db dyn HirDatabase, ) -> TypeOwnerId
We associated anon consts with their parent, because they can never have generics of their own. It can have less than the parent, but providing more generic args is not a problem.
pub(crate) fn unify(self, other: Self) -> Option<Self>
pub(crate) fn must_unify(self, other: Self) -> Self
pub(crate) fn can_rebase_into( self, db: &dyn HirDatabase, rebase_into: Self, self_ty: EarlyBinder<'_, Ty<'_>>, ) -> bool