collect_ty_garbage

Function collect_ty_garbage 

pub unsafe fn collect_ty_garbage()
Safety

This cannot be called if there are some not-yet-recorded type values. Generally, if you have a mutable reference to the database, and there are no other database - then you can call this safely, but you also need to make sure to maintain the mutable reference while this is running.