Struct ProcMacros
pub struct ProcMacros(Id);Expand description
The proc macros. Do not use Self::get! Use Self::get_for_crate instead.
Tuple Fields
0: IdImplementations
impl ProcMacros
impl ProcMacros
pub fn ingredient(db: &(dyn Database + 'static)) -> &IngredientImpl<ProcMacros>
pub fn ingredient_mut( zalsa_mut: &mut Zalsa, ) -> (&mut IngredientImpl<ProcMacros>, &mut Runtime)
impl ProcMacros
impl ProcMacros
pub fn new<Db_>(
db: &Db_,
by_crate: HashMap<Crate, Arc<CrateProcMacros>, FxBuildHasher>,
) -> ProcMacroswhere
Db_: Database + ?Sized,
pub fn builder( by_crate: HashMap<Crate, Arc<CrateProcMacros>, FxBuildHasher>, ) -> <ProcMacros as HasBuilder>::Builder
pub fn by_crate<'db, Db_>(
self,
db: &'db Db_,
) -> &'db HashMap<Crate, Arc<CrateProcMacros>, FxBuildHasher>where
Db_: Database + ?Sized,
pub fn set_by_crate<'db, Db_>(
self,
db: &'db mut Db_,
) -> impl Setter<FieldTy = HashMap<Crate, Arc<CrateProcMacros>, FxBuildHasher>>where
Db_: Database + ?Sized,
pub fn try_get<Db_>(db: &Db_) -> Option<ProcMacros>where
Db_: Database + ?Sized,
pub fn get<Db_>(db: &Db_) -> ProcMacroswhere
Db_: Database + ?Sized,
pub fn default_debug_fmt(
this: ProcMacros,
f: &mut Formatter<'_>,
) -> Result<(), Error>
pub fn default_debug_fmt( this: ProcMacros, f: &mut Formatter<'_>, ) -> Result<(), Error>
Default debug formatting for this struct (may be useful if you define your own Debug impl)
impl ProcMacros
impl ProcMacros
pub fn init_default(db: &(dyn SourceDatabase + 'static), durability: Durability)
impl ProcMacros
impl ProcMacros
pub fn get_for_crate<'db>(
db: &'db (dyn SourceDatabase + 'static),
krate: Crate,
) -> <Option<Arc<CrateProcMacros>> as SalsaAsRef>::AsRef<'db>
pub fn get_for_crate<'db>( db: &'db (dyn SourceDatabase + 'static), krate: Crate, ) -> <Option<Arc<CrateProcMacros>> as SalsaAsRef>::AsRef<'db>
Incrementality query to prevent queries from directly depending on Self::get.